@@ -1,10 +1,10 @@
 /*@z09.c:Closure Expansion:SearchEnv()@***************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.27)                       */
-/*  COPYRIGHT (C) 1991, 2002 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.29)                       */
+/*  COPYRIGHT (C) 1991, 2003 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@it.usyd.edu.au)                                */
-/*  Basser Department of Computer Science                                    */
+/*  School of Information Technologies                                       */
 /*  The University of Sydney 2006                                            */
 /*  AUSTRALIA                                                                */
 /*                                                                           */
@@ -95,6 +95,11 @@ OBJECT SetEnv(OBJECT x, OBJECT y)
 void AttachEnv(OBJECT env, OBJECT x)
 { debug2(DCE, DD, "AttachEnv( %s, %s )", EchoObject(env), EchoObject(x));
   assert( env != nilobj && type(env) == ENV, "AttachEnv: type(env) != ENV!" );
+  if( type(x) != CLOSURE && type(x) != ENV_OBJ )
+  {
+    fprintf(stderr, "AttachEnv about to fail on x = \n");
+    DebugObject(x);
+  }
   assert( type(x) == CLOSURE || type(x) == ENV_OBJ, "AttachEnv: type(x)!" );
   Link(x, env);
   debug0(DCE, DD, "AttachEnv returning.");
