@@ -1,10 +1,10 @@
 /*@z12.c:Size Finder:MinSize()@***********************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.27)                       */
-/*  COPYRIGHT (C) 1991, 2002 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.29)                       */
+/*  COPYRIGHT (C) 1991, 2003 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@it.usyd.edu.au)                                */
-/*  Basser Department of Computer Science                                    */
+/*  School of Information Technologies                                       */
 /*  The University of Sydney 2006                                            */
 /*  AUSTRALIA                                                                */
 /*                                                                           */
@@ -38,7 +38,7 @@
 
 #if DEBUG_ON
 static int debug_depth = 1;
-static int debug_depth_max = 5;
+static int debug_depth_max = 7;
 #endif
 
 /*****************************************************************************/
@@ -676,7 +676,7 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
       for( link = NextDown(Down(x));  link != x;  link = NextDown(link) )
       {
         Child(y, link);
-        New(catch_extras, ACAT)
+        New(catch_extras, ACAT);
         y = MinSize(y, dim, &catch_extras);
         if( Down(catch_extras) != catch_extras )
         {
